--creating tables

CREATE TABLE [dbo].[Instances] (
	[InstanceID] int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[Name] [varchar] (100) NOT NULL,
	[CustomerID] int NOT NULL,
	ValidTill datetime NOT NULL,
	CustomDomain varchar(100) NULL
)
GO


CREATE TABLE [dbo].[crmCompanies] (
	CompanyID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[InstanceID] int NOT NULL DEFAULT(0),
	[Name] nvarchar(500) NOT NULL,
	Website varchar(500) NULL,
	Email varchar(200) NULL,
	Phone varchar(100) NULL,
	MobilePhone varchar(100) NULL,
	Address1 nvarchar(1000) NULL,
	Address2 nvarchar(1000) NULL,
	City nvarchar(200) NULL,
	StateRegion nvarchar(200) NULL,
	Country nvarchar(200) NULL,
	PostalCode nvarchar(20) NULL,
	Comments nvarchar(max) NULL,
	LatestCommentID int NULL,
	AssignedToUserID int NULL,
	Fax varchar(100) NULL
)
GO

CREATE TABLE [dbo].[crmContacts] (
	ContactID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	InstanceID int NOT NULL DEFAULT(0),
	CompanyID int NULL,
	FirstName nvarchar(200) NOT NULL,
	LastName nvarchar(200) NOT NULL,
	Title nvarchar(200) NULL,
	Email varchar(200) NULL,
	Phone varchar(100) NULL,
	MobilePhone varchar(100) NULL,
	Address1 nvarchar(1000) NULL,
	Address2 nvarchar(1000) NULL,
	City nvarchar(200) NULL,
	StateRegion nvarchar(200) NULL,
	Country nvarchar(200) NULL,
	PostalCode nvarchar(20) NULL,
	Comments nvarchar(max) NULL,
	LatestCommentID int NULL,
	AssignedToUserID int NULL,
	Fax varchar(100) NULL
)
GO

CREATE TABLE crmCompanyImages (
	CompanyID int NOT NULL PRIMARY KEY,
	ImageFileName nvarchar(100) NOT NULL,
	ImageFileData [image] NOT NULL
)

CREATE TABLE crmContactImages (
	ContactID int NOT NULL PRIMARY KEY,
	ImageFileName nvarchar(100) NOT NULL,
	ImageFileData [image] NOT NULL
)

CREATE TABLE [dbo].[crmTags] (
	TagID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[Name] nvarchar(200) NOT NULL,
	InstanceID int NOT NULL
)
GO

CREATE TABLE [dbo].[crmComments] (
	[CommentID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[ContactID] [int] NULL,
	[CompanyID] [int] NULL,
	[ProjectID] [int] NULL,
	[CommentDate] [datetime] NOT NULL DEFAULT (getdate()),
	[UserID] [int] NULL ,
	[Body] [nvarchar] (max) NOT NULL,
	CommentType int NOT NULL DEFAULT(1),
	InstanceID int NOT NULL
)
GO

/* project tables */
CREATE TABLE crmProjects (
	[ProjectID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	InstanceID int NOT NULL DEFAULT(0),
	[Name] nvarchar(500) NOT NULL,
	IsClosed bit NOT NULL DEFAULT(0),
	LatestCommentID int NULL,
	AssignedToUserID int NULL,
	Value money NULL,
	ValueCurrency char(3) NOT NULL DEFAULT 'USD'
)
CREATE TABLE crmProjectCompanies (
	ProjectID int NOT NULL,
	CompanyID int NOT NULL
)
ALTER TABLE crmProjectCompanies WITH NOCHECK ADD CONSTRAINT [PK_crmProjectCompanies] PRIMARY KEY CLUSTERED (
	ProjectID,
	CompanyID
)
CREATE TABLE crmProjectContacts (
	ProjectID int NOT NULL,
	ContactID int NOT NULL
)
ALTER TABLE crmProjectContacts WITH NOCHECK ADD CONSTRAINT [PK_crmProjectContacts] PRIMARY KEY CLUSTERED (
	ProjectID,
	ContactID
)
GO

/* history tables */
CREATE TABLE crmContactViewHistory (
	UserID int NOT NULL,
	ContactID int NOT NULL,
	ViewDate datetime NOT NULL DEFAULT (getdate())
)
ALTER TABLE crmContactViewHistory WITH NOCHECK ADD CONSTRAINT [PK_crmContactViewHistory] PRIMARY KEY CLUSTERED (
	UserID,
	ContactID
)
CREATE TABLE crmCompanyViewHistory (
	UserID int NOT NULL,
	CompanyID int NOT NULL,
	ViewDate datetime NOT NULL DEFAULT (getdate())
)
ALTER TABLE crmCompanyViewHistory WITH NOCHECK ADD CONSTRAINT [PK_crmCompanyViewHistory] PRIMARY KEY CLUSTERED (
	UserID,
	CompanyID
)
CREATE TABLE crmProjectViewHistory (
	UserID int NOT NULL,
	ProjectID int NOT NULL,
	ViewDate datetime NOT NULL DEFAULT (getdate())
)
ALTER TABLE crmProjectViewHistory WITH NOCHECK ADD CONSTRAINT [PK_crmProjectViewHistory] PRIMARY KEY CLUSTERED (
	UserID,
	ProjectID
)
GO

CREATE TABLE [dbo].[crmContactTags] (
	TagID int NOT NULL,
	ContactID int NOT NULL
)
GO
ALTER TABLE [dbo].[crmContactTags] WITH NOCHECK ADD CONSTRAINT [PK_crmContactTags] PRIMARY KEY CLUSTERED (
	TagID,
	ContactID
)
GO


CREATE TABLE [dbo].[crmCompanyTags] (
	TagID int NOT NULL,
	CompanyID int NOT NULL
)
GO
ALTER TABLE [dbo].[crmCompanyTags] WITH NOCHECK ADD CONSTRAINT [PK_crmCompanyTags] PRIMARY KEY CLUSTERED (
	TagID,
	CompanyID
)
GO

CREATE TABLE [dbo].[crmProjectTags] (
	TagID int NOT NULL,
	ProjectID int NOT NULL
)
GO
ALTER TABLE [dbo].[crmProjectTags] WITH NOCHECK ADD CONSTRAINT [PK_crmProjectTags] PRIMARY KEY CLUSTERED (
	TagID,
	ProjectID
)
GO

/* subscription */
CREATE TABLE crmCompanySubscribers (
	CompanyID int NOT NULL,
	UserID int NOT NULL
)
ALTER TABLE crmCompanySubscribers WITH NOCHECK ADD CONSTRAINT [PK_crmCompanySubscribers] PRIMARY KEY CLUSTERED (CompanyID, UserID)

CREATE TABLE crmContactSubscribers (
	ContactID int NOT NULL,
	UserID int NOT NULL
)
ALTER TABLE crmContactSubscribers WITH NOCHECK ADD CONSTRAINT [PK_crmContactSubscribers] PRIMARY KEY CLUSTERED (ContactID, UserID)

CREATE TABLE crmProjectSubscribers (
	ProjectID int NOT NULL,
	UserID int NOT NULL
)
ALTER TABLE crmProjectSubscribers WITH NOCHECK ADD CONSTRAINT [PK_crmProjectSubscribers] PRIMARY KEY CLUSTERED (ProjectID, UserID)
GO




CREATE TABLE [dbo].[crmFileAttachments](
	[FileID] [int] IDENTITY(1,1) NOT NULL PRIMARY KEY,
	[CommentID] [int] NULL,
	[FileName] [varchar](255) NOT NULL,
	[FileData] [image] NULL,
	GoogleDriveUrl varchar(255) NULL
)

CREATE TABLE [dbo].[crmTasks](
	[TaskID] [int] IDENTITY(1,1) NOT NULL PRIMARY KEY,
	[ContactID] [int] NULL,
	[CompanyID] [int] NULL,
	[ProjectID] [int] NULL,
	[UserID] [int] NOT NULL,
	DueDate datetime NULL,
	TaskText nvarchar(2000) NOT NULL,
	IsCompleted bit NOT NULL DEFAULT(0),
	SendReminder bit NOT NULL DEFAULT 0,
	AssignedToUserID int NULL
)

CREATE TABLE [dbo].[crmSettings] (
	[InstanceID] int NOT NULL DEFAULT(0),
	AllowUserRegistration bit NOT NULL  DEFAULT (1),
	Lang [varchar] (10) NOT NULL DEFAULT ('en-US'),
	MaxAttachSize int NOT NULL DEFAULT (1000),
	[SMTPServer] [varchar] (50) NULL ,
	[SMTPAuthRequired] [bit] NOT NULL  DEFAULT (0),
	[SMTPUserName] [varchar] (50) NULL ,
	[SMTPPassword] [varchar] (50) NULL ,
	[SMTPUseSSL] [bit] NOT NULL  DEFAULT (0) ,
	[FromAddress] [varchar] (50) NULL ,
	ReplyToAddress varchar (50) NULL,
	SMTPPort int NOT NULL DEFAULT (25),
	HeaderBGColor char(6) NOT NULL DEFAULT('34383E'),
	MenuBarBGColor char(6) NOT NULL DEFAULT('4C5B6B'),
	MenuBarTabColor char(6) NOT NULL DEFAULT('D5783A'),
	UseDefaultSmtp bit NOT NULL DEFAULT 0,
	LogoImage [image] NULL,
	ServerTimeOffset int NOT NULL DEFAULT(0),
	MailCheckerEnabled bit NOT NULL DEFAULT (0),
	MailCheckerInterval int NOT NULL DEFAULT (600),
	MailCheckerPOPServer varchar (50) NULL,
	MailCheckerPOPPort int NOT NULL DEFAULT (110),
	MailCheckerPOPLogin varchar (50) NULL,
	MailCheckerPOPPassword varchar (50) NULL,
	MailCheckerUseSSL bit NOT NULL DEFAULT (0),
	MailCheckerIsImap bit NOT NULL DEFAULT (0),
	ShowTagListAsMenu bit NOT NULL DEFAULT (0),
	AutoLoginSharedSecret varchar(20) NULL,
	Title nvarchar(500) NOT NULL DEFAULT 'Jitbit CRM',
	HDRootUrl varchar(1000) not null DEFAULT '',
	HDSharedKey varchar(255) not null DEFAULT '',
	ShowEntitiesToSubscribersOnly bit not null default 0,
	MailCheckerAllowUnregisteredContacts bit NOT NULL default 0
)
GO

CREATE TABLE [dbo].[crmUsers] (
	[UserID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[InstanceID] int NOT NULL DEFAULT(0),
	[UserName] [varchar] (50) NOT NULL ,
	[email] [varchar] (50) NOT NULL ,
	[Password] [varchar] (50) NOT NULL ,
	[IsAdministrator] [bit] NOT NULL DEFAULT (0),
	[FirstName] nvarchar(255) NOT NULL DEFAULT (''),
	[LastName] nvarchar(255) NOT NULL DEFAULT (''),
	[Notes] nvarchar(max) NOT NULL DEFAULT (''),
	[Phone] varchar(50) NULL,
	[Location] nvarchar(1000) NULL,
	[Disabled] bit not null default 0,
	[EmailSignature] nvarchar(1000) NULL,
	[LastSeen] datetime null,
	[IPAddress] varchar(50) NULL
)
GO

CREATE TABLE crmUserGridColumns (
	UserID int PRIMARY KEY NOT NULL,
	ShowEmailColumn bit NOT NULL DEFAULT 0,
	ShowPhoneColumn bit NOT NULL DEFAULT 0,
	ShowFaxColumn bit NOT NULL DEFAULT 0,
	ShowAddressColumn bit NOT NULL DEFAULT 0,
	ShowCityColumn bit NOT NULL DEFAULT 0,
	ShowStateColumn bit NOT NULL DEFAULT 0,
	ShowCountryColumn bit NOT NULL DEFAULT 0,
	ShowLastNoteColumn bit NOT NULL DEFAULT 0,
	ShowAssigneeColumn bit NOT NULL DEFAULT 0,
	CustomFieldsToShowInContacts varchar(100) NOT NULL DEFAULT '',
	CustomFieldsToShowInCompanies varchar(100) NOT NULL DEFAULT ''
)

--now add constraint - unique username/instance - in crmUsers table
ALTER TABLE [dbo].[crmUsers] WITH NOCHECK ADD 
	CONSTRAINT [IX_crmUsers_UniqueNameInstance] UNIQUE  NONCLUSTERED 
	(
		[username],
		InstanceID
	)
GO

--custom fields
CREATE TABLE [dbo].[crmCustomFields] (
	[FieldID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[InstanceID] [int] NOT NULL,
	[Type] [int] NOT NULL,
	[FieldName] nvarchar(100) NOT NULL,
	[Mandatory] bit NOT NULL DEFAULT (0),
	[OrderByNumber] int NOT NULL DEFAULT (100),
	UsedForCompanies bit NOT NULL DEFAULT 0,
	UsedForContacts bit NOT NULL DEFAULT 0,
	UsedForProjects bit NOT NULL DEFAULT 0
)
GO
CREATE TABLE [dbo].[crmCustomFieldCompanyValues] (
	[CompanyID] [int] NOT NULL,
	[FieldID] [int] NOT NULL,
	[Value] sql_variant NOT NULL
)
GO
ALTER TABLE [dbo].[crmCustomFieldCompanyValues] WITH NOCHECK ADD 
	CONSTRAINT [PK_crmCustomFieldCompanyValues] PRIMARY KEY CLUSTERED 
	(
		[CompanyID],
		[FieldID]
	)
GO
CREATE TABLE [dbo].[crmCustomFieldContactValues] (
	ContactID [int] NOT NULL,
	[FieldID] [int] NOT NULL,
	[Value] sql_variant NOT NULL
)
GO
ALTER TABLE [dbo].[crmCustomFieldContactValues] WITH NOCHECK ADD 
	CONSTRAINT [PK_crmCustomFieldContactValues] PRIMARY KEY CLUSTERED 
	(
		ContactID,
		[FieldID]
	)
GO
CREATE TABLE [dbo].[crmCustomFieldProjectValues] (
	[ProjectID] [int] NOT NULL,
	[FieldID] [int] NOT NULL,
	[Value] sql_variant NOT NULL
)
ALTER TABLE [dbo].[crmCustomFieldProjectValues] WITH NOCHECK ADD 
	CONSTRAINT [PK_crmCustomFieldProjectValues] PRIMARY KEY CLUSTERED 
	(
		[ProjectID],
		[FieldID]
	)
CREATE TABLE [dbo].[crmCustomFieldOptions] (
	[OptionID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[FieldID] [int] NOT NULL,
	[OptionValue] nvarchar(500) NOT NULL
)
GO


CREATE TABLE [dbo].[crmTaskComments](
	[CommentID] [int] IDENTITY(1,1) NOT NULL,
	[TaskID] [int] NOT NULL,
	[UserID] [int] NOT NULL,
	[Body] [nvarchar](500) NOT NULL,
	[Date] [datetime] NOT NULL,
 CONSTRAINT [PK_crmTaskComments] PRIMARY KEY CLUSTERED 
(
	[CommentID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

ALTER TABLE [dbo].[crmTaskComments]  WITH CHECK ADD  CONSTRAINT [FK_crmTaskComments_crmTasks] FOREIGN KEY([TaskID])
REFERENCES [dbo].[crmTasks] ([TaskID])
GO

ALTER TABLE [dbo].[crmTaskComments] CHECK CONSTRAINT [FK_crmTaskComments_crmTasks]
GO

ALTER TABLE [dbo].[crmTaskComments]  WITH CHECK ADD  CONSTRAINT [FK_crmTaskComments_crmUsers] FOREIGN KEY([UserID])
REFERENCES [dbo].[crmUsers] ([UserID])
GO

ALTER TABLE [dbo].[crmTaskComments] CHECK CONSTRAINT [FK_crmTaskComments_crmUsers]
GO

ALTER TABLE [dbo].[crmTaskComments] ADD  CONSTRAINT [DF_crmTaskComments_Date]  DEFAULT (getdate()) FOR [Date]
GO


--create TWO PRE-DEFINED USERS
INSERT INTO crmUsers (username, email, password, IsAdministrator)
VALUES ('admin', 'admin@testmail', 'admin', 1)
GO

INSERT INTO crmUsers (username, email, password, IsAdministrator)
VALUES ('john', 'john@testmail', 'john', 0)
GO

INSERT INTO crmUsers (username, email, password, IsAdministrator)
VALUES ('jason', 'jason@testmail', 'jason', 0)
GO